Updated Branches:
  refs/heads/develop 9f3a8015b -> 04cb86c6f

Updated jenkins.sh for Mustella VM with latest FP and AIR betas

Signed-off-by: Erik de Bruin <[email protected]>


Project: http://git-wip-us.apache.org/repos/asf/flex-sdk/repo
Commit: http://git-wip-us.apache.org/repos/asf/flex-sdk/commit/04cb86c6
Tree: http://git-wip-us.apache.org/repos/asf/flex-sdk/tree/04cb86c6
Diff: http://git-wip-us.apache.org/repos/asf/flex-sdk/diff/04cb86c6

Branch: refs/heads/develop
Commit: 04cb86c6f5bc17286275df4a00003b2527be3454
Parents: 9f3a801
Author: Erik de Bruin <[email protected]>
Authored: Sun Nov 17 16:56:58 2013 +0100
Committer: Erik de Bruin <[email protected]>
Committed: Sun Nov 17 16:57:14 2013 +0100

----------------------------------------------------------------------
 mustella/jenkins.sh | 18 +++++++++---------
 1 file changed, 9 insertions(+), 9 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/04cb86c6/mustella/jenkins.sh
----------------------------------------------------------------------
diff --git a/mustella/jenkins.sh b/mustella/jenkins.sh
index 12d2d35..35b5f2f 100755
--- a/mustella/jenkins.sh
+++ b/mustella/jenkins.sh
@@ -57,20 +57,20 @@ fi
 # Toggle between versions:
 # 11.1 is the default version
 # 11.7 is the "current long term support" version
 # 11.8 is the latest release
 # 11.9 is the current beta version
 if [ "$FLASH_VERSION" == "11.1" ]
 then
   FLASH_VERSION=11.7
   AIR_VERSION=3.7
 elif [ "$FLASH_VERSION" == "11.7" ]
 then
-  FLASH_VERSION=11.8
-  AIR_VERSION=3.8
-elif [ "$FLASH_VERSION" == "11.8" ]
-then
   FLASH_VERSION=11.9
   AIR_VERSION=3.9
+elif [ "$FLASH_VERSION" == "11.9" ]
+then
+  FLASH_VERSION=12
+  AIR_VERSION=4
 else
   FLASH_VERSION=11.1
   AIR_VERSION=3.7
@@ -99,12 +99,12 @@ case "$FLASH_VERSION" in
   11.7)
     export 
FLASHPLAYER_DEBUGGER="C:\\ApacheFlex\\dependencies\\FlashPlayer_Debug\\flashplayer11_7r700_232_win_sa_debug.exe"
   ;;
-  11.8)
-    export 
FLASHPLAYER_DEBUGGER="C:\\ApacheFlex\\dependencies\\FlashPlayer_Debug\\flashplayer11_8r800_94_win_sa_debug.exe"
-  ;;
   11.9)
     export 
FLASHPLAYER_DEBUGGER="C:\\ApacheFlex\\dependencies\\FlashPlayer_Debug\\flashplayer11-9_debugsa_win_32.exe"
   ;;
+  12)
+    export 
FLASHPLAYER_DEBUGGER="C:\\ApacheFlex\\dependencies\\FlashPlayer_Debug\\flashplayer12-0_debugsa_win_32.exe"
+  ;;
   *)
     echo "No valid Flash Player Debugger variable value could be parsed."
     exit 1
@@ -57,20 +57,20 @@ fi
 # 11.1 is the default version
 # 11.7 is the "current long term support" version
-# 11.8 is the latest release
-# 11.9 is the current beta version
+# 11.9 is the latest release
+# 12 is the current beta version
 if [ "$FLASH_VERSION" == "11.1" ]
 then

Reply via email to